@@ -8,10 +8,10 @@
 #' # SEQUENCE: QWGRRCCGWGPGRRYCVRWC
 #' # Number of amino acids: 20
 #' 
-#' lengthpep("QWGRRCCGWGPGRRYCVRWC")
+#' lengthpep(seq = "QWGRRCCGWGPGRRYCVRWC")
 #' # [1] 20
 lengthpep <- function(seq) {
-  seq <- gsub("[[:space:]]+", "", seq)
+  seq <- aaCheck(seq)
   # Count the amino acids
-  nchar(seq)
+  lengths(seq)
 }
